@@ -10,6 +10,7 @@ import sys
 import json
 from pathlib import Path
 from typing import Union
+from threading import Lock
 from redis import Redis, ConnectionPool
 
 from . import logger
@@ -167,11 +168,13 @@ class MyCache(object):
 
     def __init__(self, cache_path: Union[Path, str]):
         self._dict = dict()
+        self._lock = Lock()
         self.cache_path = Path(cache_path)
         if self.cache_path.exists():
             cache = read_file_content(self.cache_path, encoding="utf-8", _return="json")
             if isinstance(cache, dict):
-                self._dict.update(cache)
+                with self._lock:
+                    self._dict.update(cache)
             else:
                 raise ValueError(f"缓存文件内容格式错误，无法转换成python dict对象：{self.cache_path}")
         else:
@@ -187,26 +190,20 @@ class MyCache(object):
         return self._dict.get(key)
 
     def delete(self, key: str):
-        if key in self._dict:
-            self._dict.pop(key)
-            self.save_cache()
+        with self._lock:
+            if key in self._dict:
+                self._dict.pop(key)
+                self.save_cache()
 
     def set(self, key: str, value):
-        self._dict[key] = value
-        self.save_cache()
+        with self._lock:
+            self._dict[key] = value
+            self.save_cache()
 
     def setex(self, name, time, value):
-        self._dict[name] = value
-        self.save_cache()
-
-    def hset(self, name, key=None, value=None, mapping=None):
-        if (key and mapping) or (not key and not mapping):
-            raise ValueError("参数key与mapping必须二选一")
-
-        if key:
-            self._dict[name][key] = value
-        else:
-            self.set(name, mapping)
+        with self._lock:
+            self._dict[name] = value
+            self.save_cache()
 
     def hmset(self, name, mapping):
         self.set(name, mapping)
@@ -223,8 +220,10 @@ class MyCache(object):
             items[key] = value
         if mapping:
             items.update(mapping)
-        self._dict[name] = items
-        self.save_cache()
+
+        with self._lock:
+            self._dict[name] = items
+            self.save_cache()
 
     def __getattr__(self, item):
         logger.warning(f"本地文件类缓存没有实现{item}方法，忽略")
